@@ -96,6 +96,9 @@ class ListAttributeAccessor:
     def __bool__(self):
         return bool(self.mapping)
 
+    def __delitem__(self, index):
+        del self.mapping[index]
+
     def __setitem__(self, key, value):
         if key >= len(self.mapping) or key < 0:
             raise IndexError("list index out of range")
@@ -504,6 +507,12 @@ class SetAttributeAccessor:
     def __rxor__(self, item):
         return set(item) ^ set(self)
 
+    def __sub__(self, item):
+        return set(self) - set(item)
+
+    def __rsub__(self, item):
+        return set(item) - set(self)
+
     def __iter__(self):
         return (self._attribute.deserialize(item) for item in self.mapping)
 
