@@ -3,12 +3,7 @@ import os
 import traceback
 from contextvars import ContextVar
 
-import transaction
-import ZODB.config
-import ZODB.DB
-import zodburi
 from sheraf.exceptions import ConnectionAlreadyOpened
-from ZODB.DemoStorage import DemoStorage
 
 
 # Isolated contexts state
@@ -142,6 +137,10 @@ class Database:
 
     def reset(self, storage=None, uri=None):
         """Close and reopen a database connection."""
+        import zodburi
+        import ZODB.DB
+        from ZODB.DemoStorage import DemoStorage
+
         if self.db:
             self.close()
 
@@ -182,6 +181,8 @@ class Database:
 
         :return: A :class:`~ZODB.Connection.Connection` object.
         """
+        import transaction
+
         data = LocalData.get()
 
         # No other connection exists
@@ -297,14 +298,18 @@ class Database:
 
         finally:
             # TODO: to be changed with try/except NoTransaction when upgrading transaction>2.0 @cedric
-            if not commit and _connection.transaction_manager:
-                _connection.transaction_manager.abort()
+            try:
+                if not commit and _connection.transaction_manager:
+                    _connection.transaction_manager.abort()
 
-            if cache_minimize:
-                for conn in _connection.connections.values():
-                    conn.cacheMinimize()
-
-            self.connection_close(_connection)
+                if cache_minimize:
+                    for conn in _connection.connections.values():
+                        conn.cacheMinimize()
+            finally:
+                # Always close the connection even if the abort raises an OperationalError.
+                # An OperationalError can be raised with RelStorage for example when the
+                # PostgreSQL server is restaring or is in recovery mode.
+                self.connection_close(_connection)
 
     @classmethod
     def last_connection(cls, database=None):
