@@ -466,34 +466,41 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
     def __setattr__(self, name, value):
         yield_callbacks = []
         attribute = self.attributes.get(name)
+        update_index = (
+            attribute
+            and attribute.indexes
+            and (not attribute.is_created(self) or getattr(self, name) != value)
+        )
 
-        if attribute and (
-            attribute.indexes or attribute.cb_creation or attribute.cb_edition
-        ):
+        if attribute and (attribute.cb_creation or attribute.cb_edition):
             if not attribute.is_created(self):
                 yield_callbacks = self.call_callbacks(
                     attribute.cb_creation, self, new=value
                 )
 
-            elif any(index.primary for index in attribute.indexes.values()):
-                raise sheraf.SherafException(
-                    f"Attribute {name} has a primary index and cannot be edited."
+            else:
+                yield_callbacks = self.call_callbacks(
+                    attribute.cb_edition, self, new=value, old=getattr(self, name)
                 )
 
-            else:
-                prev_value = getattr(self, name)
-                yield_callbacks = self.call_callbacks(
-                    attribute.cb_edition, self, new=value, old=prev_value
+        if update_index:
+            if (
+                attribute.is_created(self)
+                and attribute.has_primary_index
+                and getattr(self, name) != value
+            ):
+                raise sheraf.SherafException(
+                    f"Attribute '{name}' has a primary index and cannot be edited."
                 )
 
             old_values = self.before_index_edition(attribute)
 
         super().__setattr__(name, value)
 
-        if attribute and (
-            attribute.indexes or attribute.cb_creation or attribute.cb_edition
-        ):
+        if update_index:
             self.after_index_edition(attribute, old_values)
+
+        if yield_callbacks:
             self.call_callbacks_again(yield_callbacks)
 
     def __delattr__(self, name):
